@@ -10,6 +10,7 @@ types: list[str] = [
     "AWS::APS::RuleGroupsNamespace",
     "AWS::APS::Scraper",
     "AWS::APS::Workspace",
+    "AWS::ARCRegionSwitch::Plan",
     "AWS::ARCZonalShift::AutoshiftObserverNotificationStatus",
     "AWS::ARCZonalShift::ZonalAutoshiftConfiguration",
     "AWS::AccessAnalyzer::Analyzer",
@@ -93,6 +94,7 @@ types: list[str] = [
     "AWS::Batch::JobDefinition",
     "AWS::Batch::JobQueue",
     "AWS::Batch::SchedulingPolicy",
+    "AWS::Batch::ServiceEnvironment",
     "AWS::CDK::Metadata",
     "AWS::CertificateManager::Certificate",
     "AWS::CloudFormation::CustomResource",
@@ -237,6 +239,7 @@ types: list[str] = [
     "AWS::EC2::TransitGateway",
     "AWS::EC2::TransitGatewayAttachment",
     "AWS::EC2::TransitGatewayConnect",
+    "AWS::EC2::TransitGatewayConnectPeer",
     "AWS::EC2::TransitGatewayMulticastDomain",
     "AWS::EC2::TransitGatewayMulticastDomainAssociation",
     "AWS::EC2::TransitGatewayMulticastGroupMember",
@@ -380,9 +383,15 @@ types: list[str] = [
     "AWS::ImageBuilder::ImageRecipe",
     "AWS::ImageBuilder::InfrastructureConfiguration",
     "AWS::ImageBuilder::Workflow",
+    "AWS::IoT::Authorizer",
+    "AWS::IoT::CACertificate",
     "AWS::IoT::Certificate",
+    "AWS::IoT::CertificateProvider",
+    "AWS::IoT::DomainConfiguration",
     "AWS::IoT::Policy",
     "AWS::IoT::PolicyPrincipalAttachment",
+    "AWS::IoT::ProvisioningTemplate",
+    "AWS::IoT::RoleAlias",
     "AWS::IoT::Thing",
     "AWS::IoT::ThingPrincipalAttachment",
     "AWS::IoT::TopicRule",
@@ -577,6 +586,7 @@ types: list[str] = [
     "AWS::SageMaker::ModelPackage",
     "AWS::SageMaker::ModelPackageGroup",
     "AWS::SageMaker::Pipeline",
+    "AWS::SageMaker::ProcessingJob",
     "AWS::Scheduler::Schedule",
     "AWS::Scheduler::ScheduleGroup",
     "AWS::SecretsManager::ResourcePolicy",
@@ -644,6 +654,7 @@ cached: list[str] = [
     "aws-aiops-investigationgroup.json",
     "aws-amazonmq-broker.json",
     "aws-amazonmq-configuration.json",
+    "aws-amazonmq-configurationassociation.json",
     "aws-apigateway-account.json",
     "aws-apigateway-apikey.json",
     "aws-apigateway-authorizer.json",
@@ -700,6 +711,7 @@ cached: list[str] = [
     "aws-aps-rulegroupsnamespace.json",
     "aws-aps-scraper.json",
     "aws-aps-workspace.json",
+    "aws-arcregionswitch-plan.json",
     "aws-arczonalshift-autoshiftobservernotificationstatus.json",
     "aws-arczonalshift-zonalautoshiftconfiguration.json",
     "aws-athena-datacatalog.json",
@@ -718,8 +730,8 @@ cached: list[str] = [
     "aws-batch-computeenvironment.json",
     "aws-batch-consumableresource.json",
     "aws-batch-jobdefinition.json",
-    "aws-batch-jobqueue.json",
     "aws-batch-schedulingpolicy.json",
+    "aws-batch-serviceenvironment.json",
     "aws-certificatemanager-certificate.json",
     "aws-cloudformation-customresource.json",
     "aws-cloudformation-guardhook.json",
@@ -848,6 +860,7 @@ cached: list[str] = [
     "aws-ec2-transitgateway.json",
     "aws-ec2-transitgatewayattachment.json",
     "aws-ec2-transitgatewayconnect.json",
+    "aws-ec2-transitgatewayconnectpeer.json",
     "aws-ec2-transitgatewaymulticastdomain.json",
     "aws-ec2-transitgatewaymulticastdomainassociation.json",
     "aws-ec2-transitgatewaymulticastgroupmember.json",
@@ -907,7 +920,6 @@ cached: list[str] = [
     "aws-elasticache-usergroup.json",
     "aws-elasticloadbalancing-loadbalancer.json",
     "aws-elasticloadbalancingv2-listenercertificate.json",
-    "aws-elasticloadbalancingv2-listenerrule.json",
     "aws-elasticloadbalancingv2-loadbalancer.json",
     "aws-elasticloadbalancingv2-targetgroup.json",
     "aws-elasticloadbalancingv2-truststore.json",
@@ -977,6 +989,14 @@ cached: list[str] = [
     "aws-imagebuilder-imagerecipe.json",
     "aws-imagebuilder-infrastructureconfiguration.json",
     "aws-imagebuilder-workflow.json",
+    "aws-iot-authorizer.json",
+    "aws-iot-cacertificate.json",
+    "aws-iot-certificate.json",
+    "aws-iot-certificateprovider.json",
+    "aws-iot-domainconfiguration.json",
+    "aws-iot-policy.json",
+    "aws-iot-provisioningtemplate.json",
+    "aws-iot-rolealias.json",
     "aws-iot-thingprincipalattachment.json",
     "aws-kinesis-resourcepolicy.json",
     "aws-kinesis-stream.json",
@@ -1010,8 +1030,6 @@ cached: list[str] = [
     "aws-logs-delivery.json",
     "aws-logs-deliverydestination.json",
     "aws-logs-deliverysource.json",
-    "aws-logs-destination.json",
-    "aws-logs-loggroup.json",
     "aws-logs-logstream.json",
     "aws-logs-metricfilter.json",
     "aws-logs-querydefinition.json",
@@ -1029,7 +1047,6 @@ cached: list[str] = [
     "aws-neptune-dbinstance.json",
     "aws-neptune-dbparametergroup.json",
     "aws-neptune-dbsubnetgroup.json",
-    "aws-neptune-eventsubscription.json",
     "aws-networkfirewall-firewall.json",
     "aws-networkfirewall-firewallpolicy.json",
     "aws-networkfirewall-loggingconfiguration.json",
@@ -1133,6 +1150,7 @@ cached: list[str] = [
     "aws-sagemaker-modelpackage.json",
     "aws-sagemaker-modelpackagegroup.json",
     "aws-sagemaker-pipeline.json",
+    "aws-sagemaker-processingjob.json",
     "aws-scheduler-schedule.json",
     "aws-scheduler-schedulegroup.json",
     "aws-sdb-domain.json",
