@@ -9,6 +9,7 @@ types: list[str] = [
     "AWS::APS::RuleGroupsNamespace",
     "AWS::APS::Scraper",
     "AWS::APS::Workspace",
+    "AWS::ARCRegionSwitch::Plan",
     "AWS::ARCZonalShift::AutoshiftObserverNotificationStatus",
     "AWS::ARCZonalShift::ZonalAutoshiftConfiguration",
     "AWS::AccessAnalyzer::Analyzer",
@@ -134,6 +135,7 @@ types: list[str] = [
     "AWS::Batch::JobDefinition",
     "AWS::Batch::JobQueue",
     "AWS::Batch::SchedulingPolicy",
+    "AWS::Batch::ServiceEnvironment",
     "AWS::Bedrock::Agent",
     "AWS::Bedrock::AgentAlias",
     "AWS::Bedrock::ApplicationInferenceProfile",
@@ -422,6 +424,7 @@ types: list[str] = [
     "AWS::EC2::TransitGateway",
     "AWS::EC2::TransitGatewayAttachment",
     "AWS::EC2::TransitGatewayConnect",
+    "AWS::EC2::TransitGatewayConnectPeer",
     "AWS::EC2::TransitGatewayMulticastDomain",
     "AWS::EC2::TransitGatewayMulticastDomainAssociation",
     "AWS::EC2::TransitGatewayMulticastGroupMember",
@@ -1051,6 +1054,7 @@ types: list[str] = [
     "AWS::SageMaker::NotebookInstanceLifecycleConfig",
     "AWS::SageMaker::PartnerApp",
     "AWS::SageMaker::Pipeline",
+    "AWS::SageMaker::ProcessingJob",
     "AWS::SageMaker::Project",
     "AWS::SageMaker::Space",
     "AWS::SageMaker::StudioLifecycleConfig",
@@ -1310,6 +1314,7 @@ cached: list[str] = [
     "aws-aps-rulegroupsnamespace.json",
     "aws-aps-scraper.json",
     "aws-aps-workspace.json",
+    "aws-arcregionswitch-plan.json",
     "aws-arczonalshift-autoshiftobservernotificationstatus.json",
     "aws-arczonalshift-zonalautoshiftconfiguration.json",
     "aws-athena-datacatalog.json",
@@ -1336,8 +1341,8 @@ cached: list[str] = [
     "aws-batch-computeenvironment.json",
     "aws-batch-consumableresource.json",
     "aws-batch-jobdefinition.json",
-    "aws-batch-jobqueue.json",
     "aws-batch-schedulingpolicy.json",
+    "aws-batch-serviceenvironment.json",
     "aws-bedrock-agent.json",
     "aws-bedrock-agentalias.json",
     "aws-bedrock-applicationinferenceprofile.json",
@@ -1619,6 +1624,7 @@ cached: list[str] = [
     "aws-ec2-transitgateway.json",
     "aws-ec2-transitgatewayattachment.json",
     "aws-ec2-transitgatewayconnect.json",
+    "aws-ec2-transitgatewayconnectpeer.json",
     "aws-ec2-transitgatewaymulticastdomain.json",
     "aws-ec2-transitgatewaymulticastdomainassociation.json",
     "aws-ec2-transitgatewaymulticastgroupmember.json",
@@ -1877,6 +1883,7 @@ cached: list[str] = [
     "aws-lambda-layerversionpermission.json",
     "aws-lambda-permission.json",
     "aws-lambda-url.json",
+    "aws-lambda-version.json",
     "aws-launchwizard-deployment.json",
     "aws-lex-bot.json",
     "aws-lex-botalias.json",
@@ -1905,10 +1912,8 @@ cached: list[str] = [
     "aws-logs-delivery.json",
     "aws-logs-deliverydestination.json",
     "aws-logs-deliverysource.json",
-    "aws-logs-destination.json",
     "aws-logs-integration.json",
     "aws-logs-loganomalydetector.json",
-    "aws-logs-loggroup.json",
     "aws-logs-logstream.json",
     "aws-logs-metricfilter.json",
     "aws-logs-querydefinition.json",
@@ -1975,7 +1980,6 @@ cached: list[str] = [
     "aws-neptune-dbinstance.json",
     "aws-neptune-dbparametergroup.json",
     "aws-neptune-dbsubnetgroup.json",
-    "aws-neptune-eventsubscription.json",
     "aws-networkfirewall-firewall.json",
     "aws-networkfirewall-firewallpolicy.json",
     "aws-networkfirewall-loggingconfiguration.json",
@@ -2070,8 +2074,8 @@ cached: list[str] = [
     "aws-ram-resourceshare.json",
     "aws-rbin-rule.json",
     "aws-rds-customdbengineversion.json",
-    "aws-rds-dbcluster.json",
     "aws-rds-dbclusterparametergroup.json",
+    "aws-rds-dbinstance.json",
     "aws-rds-dbparametergroup.json",
     "aws-rds-dbproxy.json",
     "aws-rds-dbproxyendpoint.json",
@@ -2169,6 +2173,7 @@ cached: list[str] = [
     "aws-sagemaker-notebookinstancelifecycleconfig.json",
     "aws-sagemaker-partnerapp.json",
     "aws-sagemaker-pipeline.json",
+    "aws-sagemaker-processingjob.json",
     "aws-sagemaker-project.json",
     "aws-sagemaker-space.json",
     "aws-sagemaker-studiolifecycleconfig.json",
