@@ -242,6 +242,7 @@ types: list[str] = [
     "AWS::EC2::TransitGateway",
     "AWS::EC2::TransitGatewayAttachment",
     "AWS::EC2::TransitGatewayConnect",
+    "AWS::EC2::TransitGatewayConnectPeer",
     "AWS::EC2::TransitGatewayMulticastDomain",
     "AWS::EC2::TransitGatewayMulticastDomainAssociation",
     "AWS::EC2::TransitGatewayMulticastGroupMember",
@@ -666,6 +667,7 @@ types: list[str] = [
     "AWS::SageMaker::NotebookInstance",
     "AWS::SageMaker::NotebookInstanceLifecycleConfig",
     "AWS::SageMaker::Pipeline",
+    "AWS::SageMaker::ProcessingJob",
     "AWS::SageMaker::Project",
     "AWS::SageMaker::StudioLifecycleConfig",
     "AWS::SageMaker::UserProfile",
@@ -976,6 +978,7 @@ cached: list[str] = [
     "aws-ec2-transitgateway.json",
     "aws-ec2-transitgatewayattachment.json",
     "aws-ec2-transitgatewayconnect.json",
+    "aws-ec2-transitgatewayconnectpeer.json",
     "aws-ec2-transitgatewaymulticastdomain.json",
     "aws-ec2-transitgatewaymulticastdomainassociation.json",
     "aws-ec2-transitgatewaymulticastgroupmember.json",
@@ -1010,7 +1013,6 @@ cached: list[str] = [
     "aws-ecs-clustercapacityproviderassociations.json",
     "aws-ecs-primarytaskset.json",
     "aws-ecs-service.json",
-    "aws-ecs-taskdefinition.json",
     "aws-ecs-taskset.json",
     "aws-efs-accesspoint.json",
     "aws-efs-filesystem.json",
@@ -1038,6 +1040,7 @@ cached: list[str] = [
     "aws-elasticloadbalancing-loadbalancer.json",
     "aws-elasticloadbalancingv2-listener.json",
     "aws-elasticloadbalancingv2-listenercertificate.json",
+    "aws-elasticloadbalancingv2-listenerrule.json",
     "aws-elasticloadbalancingv2-loadbalancer.json",
     "aws-elasticloadbalancingv2-targetgroup.json",
     "aws-elasticloadbalancingv2-truststore.json",
@@ -1083,6 +1086,7 @@ cached: list[str] = [
     "aws-glue-datacatalogencryptionsettings.json",
     "aws-glue-dataqualityruleset.json",
     "aws-glue-devendpoint.json",
+    "aws-glue-job.json",
     "aws-glue-mltransform.json",
     "aws-glue-partition.json",
     "aws-glue-registry.json",
@@ -1154,7 +1158,6 @@ cached: list[str] = [
     "aws-iot-custommetric.json",
     "aws-iot-dimension.json",
     "aws-iot-domainconfiguration.json",
-    "aws-iot-fleetmetric.json",
     "aws-iot-jobtemplate.json",
     "aws-iot-logging.json",
     "aws-iot-mitigationaction.json",
@@ -1222,8 +1225,6 @@ cached: list[str] = [
     "aws-logs-delivery.json",
     "aws-logs-deliverydestination.json",
     "aws-logs-deliverysource.json",
-    "aws-logs-destination.json",
-    "aws-logs-loggroup.json",
     "aws-logs-logstream.json",
     "aws-logs-metricfilter.json",
     "aws-logs-querydefinition.json",
@@ -1246,11 +1247,7 @@ cached: list[str] = [
     "aws-neptune-dbinstance.json",
     "aws-neptune-dbparametergroup.json",
     "aws-neptune-dbsubnetgroup.json",
-    "aws-neptune-eventsubscription.json",
-    "aws-networkfirewall-firewall.json",
-    "aws-networkfirewall-firewallpolicy.json",
     "aws-networkfirewall-loggingconfiguration.json",
-    "aws-networkfirewall-rulegroup.json",
     "aws-networkfirewall-tlsinspectionconfiguration.json",
     "aws-networkfirewall-vpcendpointassociation.json",
     "aws-oam-link.json",
