@@ -9,6 +9,7 @@ types: list[str] = [
     "AWS::APS::RuleGroupsNamespace",
     "AWS::APS::Scraper",
     "AWS::APS::Workspace",
+    "AWS::ARCRegionSwitch::Plan",
     "AWS::ARCZonalShift::AutoshiftObserverNotificationStatus",
     "AWS::ARCZonalShift::ZonalAutoshiftConfiguration",
     "AWS::AccessAnalyzer::Analyzer",
@@ -99,6 +100,7 @@ types: list[str] = [
     "AWS::Batch::JobDefinition",
     "AWS::Batch::JobQueue",
     "AWS::Batch::SchedulingPolicy",
+    "AWS::Batch::ServiceEnvironment",
     "AWS::CDK::Metadata",
     "AWS::CE::AnomalyMonitor",
     "AWS::CE::AnomalySubscription",
@@ -273,6 +275,7 @@ types: list[str] = [
     "AWS::EC2::TransitGateway",
     "AWS::EC2::TransitGatewayAttachment",
     "AWS::EC2::TransitGatewayConnect",
+    "AWS::EC2::TransitGatewayConnectPeer",
     "AWS::EC2::TransitGatewayMulticastDomain",
     "AWS::EC2::TransitGatewayMulticastDomainAssociation",
     "AWS::EC2::TransitGatewayMulticastGroupMember",
@@ -581,6 +584,7 @@ types: list[str] = [
     "AWS::PCAConnectorSCEP::Challenge",
     "AWS::PCAConnectorSCEP::Connector",
     "AWS::Pipes::Pipe",
+    "AWS::QuickSight::RefreshSchedule",
     "AWS::RAM::Permission",
     "AWS::RAM::ResourceShare",
     "AWS::RDS::DBCluster",
@@ -695,6 +699,7 @@ types: list[str] = [
     "AWS::SageMaker::ModelCard",
     "AWS::SageMaker::ModelPackage",
     "AWS::SageMaker::ModelPackageGroup",
+    "AWS::SageMaker::ProcessingJob",
     "AWS::SageMaker::Project",
     "AWS::SageMaker::Space",
     "AWS::SageMaker::StudioLifecycleConfig",
@@ -863,6 +868,7 @@ cached: list[str] = [
     "aws-aps-rulegroupsnamespace.json",
     "aws-aps-scraper.json",
     "aws-aps-workspace.json",
+    "aws-arcregionswitch-plan.json",
     "aws-arczonalshift-autoshiftobservernotificationstatus.json",
     "aws-arczonalshift-zonalautoshiftconfiguration.json",
     "aws-athena-datacatalog.json",
@@ -886,8 +892,8 @@ cached: list[str] = [
     "aws-batch-computeenvironment.json",
     "aws-batch-consumableresource.json",
     "aws-batch-jobdefinition.json",
-    "aws-batch-jobqueue.json",
     "aws-batch-schedulingpolicy.json",
+    "aws-batch-serviceenvironment.json",
     "aws-ce-anomalymonitor.json",
     "aws-ce-anomalysubscription.json",
     "aws-certificatemanager-certificate.json",
@@ -941,6 +947,7 @@ cached: list[str] = [
     "aws-codedeploy-application.json",
     "aws-codedeploy-deploymentconfig.json",
     "aws-codedeploy-deploymentgroup.json",
+    "aws-codepipeline-customactiontype.json",
     "aws-codepipeline-pipeline.json",
     "aws-cognito-identitypool.json",
     "aws-cognito-identitypoolprincipaltag.json",
@@ -1048,6 +1055,7 @@ cached: list[str] = [
     "aws-ec2-transitgateway.json",
     "aws-ec2-transitgatewayattachment.json",
     "aws-ec2-transitgatewayconnect.json",
+    "aws-ec2-transitgatewayconnectpeer.json",
     "aws-ec2-transitgatewaymulticastdomain.json",
     "aws-ec2-transitgatewaymulticastdomainassociation.json",
     "aws-ec2-transitgatewaymulticastgroupmember.json",
@@ -1247,13 +1255,12 @@ cached: list[str] = [
     "aws-lambda-layerversion.json",
     "aws-lambda-layerversionpermission.json",
     "aws-lambda-permission.json",
+    "aws-lambda-version.json",
     "aws-launchwizard-deployment.json",
     "aws-logs-delivery.json",
     "aws-logs-deliverydestination.json",
     "aws-logs-deliverysource.json",
-    "aws-logs-destination.json",
     "aws-logs-loganomalydetector.json",
-    "aws-logs-loggroup.json",
     "aws-logs-logstream.json",
     "aws-logs-metricfilter.json",
     "aws-logs-querydefinition.json",
@@ -1297,11 +1304,7 @@ cached: list[str] = [
     "aws-neptune-dbinstance.json",
     "aws-neptune-dbparametergroup.json",
     "aws-neptune-dbsubnetgroup.json",
-    "aws-neptune-eventsubscription.json",
-    "aws-networkfirewall-firewall.json",
-    "aws-networkfirewall-firewallpolicy.json",
     "aws-networkfirewall-loggingconfiguration.json",
-    "aws-networkfirewall-rulegroup.json",
     "aws-networkfirewall-tlsinspectionconfiguration.json",
     "aws-networkfirewall-vpcendpointassociation.json",
     "aws-networkmanager-connectattachment.json",
@@ -1339,11 +1342,12 @@ cached: list[str] = [
     "aws-pcaconnectorscep-challenge.json",
     "aws-pcaconnectorscep-connector.json",
     "aws-pipes-pipe.json",
+    "aws-quicksight-refreshschedule.json",
     "aws-ram-permission.json",
     "aws-ram-resourceshare.json",
     "aws-rbin-rule.json",
-    "aws-rds-dbcluster.json",
     "aws-rds-dbclusterparametergroup.json",
+    "aws-rds-dbinstance.json",
     "aws-rds-dbparametergroup.json",
     "aws-rds-dbproxy.json",
     "aws-rds-dbproxyendpoint.json",
