@@ -10,6 +10,7 @@ types: list[str] = [
     "AWS::APS::RuleGroupsNamespace",
     "AWS::APS::Scraper",
     "AWS::APS::Workspace",
+    "AWS::ARCRegionSwitch::Plan",
     "AWS::ARCZonalShift::AutoshiftObserverNotificationStatus",
     "AWS::ARCZonalShift::ZonalAutoshiftConfiguration",
     "AWS::AccessAnalyzer::Analyzer",
@@ -476,6 +477,7 @@ types: list[str] = [
     "AWS::EC2::TransitGateway",
     "AWS::EC2::TransitGatewayAttachment",
     "AWS::EC2::TransitGatewayConnect",
+    "AWS::EC2::TransitGatewayConnectPeer",
     "AWS::EC2::TransitGatewayMulticastDomain",
     "AWS::EC2::TransitGatewayMulticastDomainAssociation",
     "AWS::EC2::TransitGatewayMulticastGroupMember",
@@ -769,6 +771,7 @@ types: list[str] = [
     "AWS::IoTSiteWise::AccessPolicy",
     "AWS::IoTSiteWise::Asset",
     "AWS::IoTSiteWise::AssetModel",
+    "AWS::IoTSiteWise::ComputationModel",
     "AWS::IoTSiteWise::Dashboard",
     "AWS::IoTSiteWise::Dataset",
     "AWS::IoTSiteWise::Gateway",
@@ -1269,6 +1272,7 @@ types: list[str] = [
     "AWS::SageMaker::NotebookInstanceLifecycleConfig",
     "AWS::SageMaker::PartnerApp",
     "AWS::SageMaker::Pipeline",
+    "AWS::SageMaker::ProcessingJob",
     "AWS::SageMaker::Project",
     "AWS::SageMaker::Space",
     "AWS::SageMaker::StudioLifecycleConfig",
